@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.21';
+$VERSION = '1.22';
 
 #----------------------------------------------------------------------------
 
@@ -66,6 +66,7 @@ use Sort::Versions;
 use Template;
 #use Time::HiRes qw ( time );
 use Time::Piece;
+use Try::Tiny;
 
 # -------------------------------------
 # Variables
@@ -582,11 +583,17 @@ sub storage_read {
 
 #    for $type (qw(stats dists fails perls pass platform osys osname build counts count xrefs xlast)) {
     for $type (qw(stats dists fails perls platform osys osname build counts count xrefs xlast)) {
+$self->{parent}->_log("storage_read:1.type=$type");
         my $storage = sprintf $self->{parent}->mainstore(), $type;
         next    unless(-f $storage);
-        my $data = read_file($storage);
-        my $store = decode_json($data);
-        $self->{$type} = $store->{$type};
+$self->{parent}->_log("storage_read:2.storage=$storage");
+        try {
+            my $data = read_file($storage);
+            my $store = decode_json($data);
+            $self->{$type} = $store->{$type};
+        } catch {
+$self->{parent}->_log("storage_read:3.failed to read data storage=$storage");
+        };
     }
 }
 
@@ -2082,7 +2089,13 @@ sub _build_performance_stats {
     my $fh = IO::File->new(">$results/build1.txt");
     print $fh "#DATE,REQUESTS,PAGES,REPORTS\n";
 
+    my $count = scalar(keys %{$self->{build}});
+    my $limit = $self->{parent}->build_history || 90;
+    my $diff  = $count - $limit;
+
     for my $date (sort {$a <=> $b} keys %{$self->{build}}) {
+        next    if(--$diff > 0);
+
 #$self->{parent}->_log("build_stats: date=$date, old=$self->{build}{$date}->{old}");
 	next	if($self->{build}{$date}->{old} == 2);	# ignore todays tally
         #next    if($date > $self->{dates}{THISMONTH}-1);
@@ -2247,7 +2260,7 @@ F<http://wiki.cpantesters.org/>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (C) 2005-2015 Barbie for Miss Barbell Productions.
+  Copyright (C) 2005-2017 Barbie for Miss Barbell Productions.
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
